@@ -1,5 +1,5 @@
 /* cfg.h -- general-purpose configuration file parser 
-   Copyright (C) 2007-2021 Free Software Foundation, Inc.
+   Copyright (C) 2007-2023 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -97,7 +97,7 @@ struct mu_cfg_parse_hints
    site-wide configuration */
 #define MU_CFHINT_PER_USER_FILE      0x0008
 
-/* Don't allow to overide configuration settings from the command line. */
+/* Don't allow to override configuration settings from the command line. */
 #define MU_CFHINT_NO_CONFIG_OVERRIDE 0x0010
 	
 /* Verbosely log files being processed */
@@ -192,6 +192,8 @@ struct mu_cfg_section
   void *target;                   /* Actual pointer to the data. It is
 				     recomputed each time the section is
 				     reduced. */
+  char *ident_storage;            /* Storage for ident, if malloc'ed */
+  char *label_storage;            /* Same for the label */
 };
 
 enum mu_cfg_cont_type
